summaryrefslogtreecommitdiffstats
path: root/kword/KWVariable.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kword/KWVariable.cpp')
-rw-r--r--kword/KWVariable.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kword/KWVariable.cpp b/kword/KWVariable.cpp
index 5b82b220..80666965 100644
--- a/kword/KWVariable.cpp
+++ b/kword/KWVariable.cpp
@@ -351,7 +351,7 @@ void KWFootNoteVariable::saveOasis( KoXmlWriter& writer, KoSavingContext& contex
writer.startElement( "text:note-citation" );
if ( m_numberingType == Auto )
- writer.addTextNode( TQString( "%1" ).tqarg( m_numDisplay ) );
+ writer.addTextNode( TQString( "%1" ).arg( m_numDisplay ) );
else
{
writer.addAttribute( "text:label", m_varValue.toString() );
@@ -478,7 +478,7 @@ TQString KWFootNoteVariable::text(bool realValue)
void KWFootNoteVariable::setNumDisplay( int val )
{
m_numDisplay = val;
- if ( val != -1 ) // -1 is used to 'tqinvalidate so that renumberFootNotes recalcs'
+ if ( val != -1 ) // -1 is used to 'invalidate so that renumberFootNotes recalcs'
formatedNote();
}
@@ -532,7 +532,7 @@ void KWFootNoteVariable::finalize()
fs->textObject()->abortFormatting();
// abortFormatting is a bool in kotextobject. So we need to return there before
// starting text tqlayout again.
m_doc->delayedRecalcFrames( TQMIN( pageNum, framePage ) );
m_doc->delayedRepaintAllViews();
}
@@ -596,7 +596,7 @@ void KWFootNoteVariable::setDeleted( bool del )
m_doc->recalcFrames();
if (!del)
- m_frameset->tqlayout(); // format its text, so that it resizes the frame
+ m_frameset->layout(); // format its text, so that it resizes the frame
KoVariable::setDeleted( del );
// Does this compress? Probably not.
m_doc->delayedRepaintAllViews();
@@ -617,7 +617,7 @@ double KWFootNoteVariable::varY() const
if ( !fs->hasFramesInPageArray() ) // we need it for internalToDocument
{
kdDebug(32001) << "KWFootNoteVariable::varY too early, no updateFrames yet" << endl;
- return 0; // this happens on loading - frame tqlayout is done before text tqlayout
+ return 0; // this happens on loading - frame layout is done before text layout
}
// What we need is "has never been formatted". Not "has just been invalidated"...
//if ( !paragraph()->isValid() )
@@ -532,7 +532,7 @@ void KWFootNoteVariable::finalize()
fs->textObject()->abortFormatting();
// abortFormatting is a bool in kotextobject. So we need to return there before
- // starting text tqlayout again.
+ // starting text layout again.
m_doc->delayedRecalcFrames( TQMIN( pageNum, framePage ) );
m_doc->delayedRepaintAllViews();